aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorStanislav Ionascu <stanislav.ionascu@nokia.com>2010-12-23 14:18:42 +0200
committerStanislav Ionascu <stanislav.ionascu@nokia.com>2010-12-23 14:18:42 +0200
commit22f12afd155ad852bcd0d1239c5a0f7aa9338a3e (patch)
tree5aca3673927e046073220d028b9e5857a28f3941 /tests
parent49649d135169d27acd6eb9b9984ed6e6e1711367 (diff)
Changes: Fixes ut_mremoteaction unit test.
RevBy: TrustMe. Details: The unit test was using incorrect stubs (which were changed in commit 0b47d6ad1dd85fbcb2ef46161d82fd0b55cc0248)
Diffstat (limited to 'tests')
-rw-r--r--tests/ut_mremoteaction/ut_mremoteaction.cpp13
1 files changed, 7 insertions, 6 deletions
diff --git a/tests/ut_mremoteaction/ut_mremoteaction.cpp b/tests/ut_mremoteaction/ut_mremoteaction.cpp
index 1c4aa3b9..8c4639db 100644
--- a/tests/ut_mremoteaction/ut_mremoteaction.cpp
+++ b/tests/ut_mremoteaction/ut_mremoteaction.cpp
@@ -18,9 +18,10 @@
****************************************************************************/
#include "ut_mremoteaction.h"
-#include <QDBusInterface>
+#include "mdbusinterface.h"
#include <maction_stub.h>
#include "maction_p.h"
+#include <QDBusPendingCall>
bool Ut_MRemoteAction::captureCalls = false;
QString Ut_MRemoteAction::callServiceName;
@@ -39,27 +40,27 @@ MActionPrivate::~MActionPrivate()
{
}
-// QDBusInterface stubs (used by MRemoteAction)
-QDBusInterface::QDBusInterface(const QString &service, const QString &path, const QString &interface, const QDBusConnection &connection, QObject *parent) : QDBusAbstractInterface(service, path, interface.toUtf8().constData(), connection, parent)
+// MDBusInterface stubs (used by MRemoteAction)
+MDBusInteface::MDBusInteface(const QString &service, const QString &path, const char *interface, const QDBusConnection &connection, QObject *parent) : QDBusAbstractInterface(service, path, interface, connection, parent)
{
Ut_MRemoteAction::callServiceName = service;
Ut_MRemoteAction::callObjectPath = path;
Ut_MRemoteAction::callInterface = interface;
}
-QDBusInterface::~QDBusInterface()
+MDBusInteface::~MDBusInteface()
{
}
// QDBusAbstractInterface stubs (used by MRemoteAction)
-QDBusMessage QDBusAbstractInterface::callWithArgumentList(QDBus::CallMode, const QString &method, const QList<QVariant> &args)
+QDBusPendingCall QDBusAbstractInterface::asyncCallWithArgumentList(const QString &method, const QList<QVariant> &args)
{
if (Ut_MRemoteAction::captureCalls) {
Ut_MRemoteAction::callMethods.append(method);
Ut_MRemoteAction::callArguments.append(args);
}
- return QDBusMessage();
+ return QDBusPendingCall::fromCompletedCall(QDBusMessage());
}
void Ut_MRemoteAction::init()